@@ -914,20 +914,6 @@ lcCommand gCommands[LC_NUM_COMMANDS] =
 		"Go to the last step of the model",
 		"Alt+Down"
 	},
-	// LC_VIEW_TIME_STOP
-	{
-		"View.Time.Stop",
-		"Stop",
-		"Stop playing animation",
-		""
-	},
-	// LC_VIEW_TIME_PLAY
-	{
-		"View.Time.Play",
-		"Play",
-		"Play animation",
-		""
-	},
 	// LC_VIEW_TIME_INSERT
 	{
 		"View.Time.Insert",
@@ -942,13 +928,6 @@ lcCommand gCommands[LC_NUM_COMMANDS] =
 		"Delete current step",
 		""
 	},
-	// LC_VIEW_TIME_ANIMATION
-	{
-		"View.Time.Animation",
-		"Animation",
-		"Toggle between animation and instruction mode",
-		""
-	},
 	// LC_VIEW_TIME_ADD_KEYS
 	{
 		"View.Time.AddKeys",
