@@ -139,11 +139,8 @@ enum LC_COMMANDS
 	LC_VIEW_TIME_PREVIOUS,
 	LC_VIEW_TIME_NEXT,
 	LC_VIEW_TIME_LAST,
-	LC_VIEW_TIME_STOP,
-	LC_VIEW_TIME_PLAY,
 	LC_VIEW_TIME_INSERT,
 	LC_VIEW_TIME_DELETE,
-	LC_VIEW_TIME_ANIMATION,
 	LC_VIEW_TIME_ADD_KEYS,
 	LC_VIEW_SPLIT_HORIZONTAL,
 	LC_VIEW_SPLIT_VERTICAL,
