@@ -12,6 +12,7 @@
 #include "camera.h"
 #include "system.h"
 #include "lc_texture.h"
+#include "lc_profile.h"
 
 /////////////////////////////////////////////////////////////////////////////
 // Static functions
@@ -593,7 +594,6 @@ float tx, ty;
 tx = (tw*eye[0])/(2*pCam->m_zFar);
 ty = (th*eye[1])/(2*pCam->m_zFar);
 
-			glEnableClientState(GL_VERTEX_ARRAY);
 			glEnableClientState(GL_TEXTURE_COORD_ARRAY);
 
 			float Quad[20] =
@@ -610,7 +610,6 @@ ty = (th*eye[1])/(2*pCam->m_zFar);
 			glDrawArrays(GL_QUADS, 0, 4);
 
 			glDisableClientState(GL_TEXTURE_COORD_ARRAY);
-			glDisableClientState(GL_VERTEX_ARRAY);
 
 			glDisable(GL_TEXTURE_2D);
 		}
@@ -626,12 +625,9 @@ ty = (th*eye[1])/(2*pCam->m_zFar);
 
 			glColor4f(m_fColor[0], m_fColor[1], m_fColor[2], 1.0f);
 
-			glEnableClientState(GL_VERTEX_ARRAY);
 			glVertexPointer(3, GL_FLOAT, 0, Quad);
 
 			glDrawArrays(GL_QUADS, 0, 4);
-
-			glDisableClientState(GL_VERTEX_ARRAY);
 		}
 
 		glPopMatrix();
@@ -642,7 +638,6 @@ ty = (th*eye[1])/(2*pCam->m_zFar);
 
 		int i, j;
 		glColor4f(m_fColor[0], m_fColor[1], m_fColor[2], 1.0f);
-		glEnableClientState(GL_VERTEX_ARRAY);
 
 		if (m_nOptions & LC_TERRAIN_TEXTURE)
 		{
@@ -678,8 +673,6 @@ ty = (th*eye[1])/(2*pCam->m_zFar);
 			glDisable(GL_TEXTURE_2D);
 			glDisableClientState(GL_TEXTURE_COORD_ARRAY);
 		}
-
-		glDisableClientState(GL_VERTEX_ARRAY);
 	}
 }
 
@@ -809,7 +802,7 @@ void Terrain::FindVisiblePatches(Camera* pCam, float aspect)
 
 void Terrain::LoadDefaults(bool bLinear)
 {
-	unsigned long rgb = Sys_ProfileLoadInt ("Default", "Floor", RGB (0,191,0));
+	unsigned long rgb = lcGetProfileInt(LC_PROFILE_DEFAULT_FLOOR_COLOR);
 	m_fColor[0] = (float)((unsigned char) (rgb))/255;
 	m_fColor[1] = (float)((unsigned char) (((unsigned short) (rgb)) >> 8))/255;
 	m_fColor[2] = (float)((unsigned char) ((rgb) >> 16))/255;
@@ -817,7 +810,7 @@ void Terrain::LoadDefaults(bool bLinear)
 	m_uSize = 50;
 	m_vSize = 50;
 
-	strcpy (m_strTexture, Sys_ProfileLoadString ("Default", "FloorBMP", ""));
+	strcpy(m_strTexture, lcGetProfileString(LC_PROFILE_DEFAULT_FLOOR_TEXTURE));
 	m_pTexture->Unload();
 
 	m_nOptions = LC_TERRAIN_FLAT;
