@@ -3,7 +3,7 @@
 #include "ui_lc_qpreferencesdialog.h"
 #include "lc_qutils.h"
 #include "lc_qcategorydialog.h"
-#include "basewnd.h"
+#include "lc_basewindow.h"
 #include "lc_library.h"
 #include "lc_application.h"
 #include "pieceinf.h"
@@ -15,6 +15,8 @@ lcQPreferencesDialog::lcQPreferencesDialog(QWidget *parent, void *data) :
     ui->setupUi(this);
 
 	ui->lineWidth->setValidator(new QDoubleValidator());
+	connect(ui->gridStudColor, SIGNAL(clicked()), this, SLOT(colorClicked()));
+	connect(ui->gridLineColor, SIGNAL(clicked()), this, SLOT(colorClicked()));
 	connect(ui->categoriesTree, SIGNAL(itemSelectionChanged()), this, SLOT(updateParts()));
 	ui->shortcutEdit->installEventFilter(this);
 	connect(ui->commandList, SIGNAL(currentItemChanged(QTreeWidgetItem*, QTreeWidgetItem*)), this, SLOT(commandChanged(QTreeWidgetItem*)));
@@ -24,8 +26,10 @@ lcQPreferencesDialog::lcQPreferencesDialog(QWidget *parent, void *data) :
 	ui->authorName->setText(options->DefaultAuthor);
 	ui->projectsFolder->setText(options->ProjectsPath);
 	ui->partsLibrary->setText(options->LibraryPath);
-	ui->mouseSensitivity->setValue(options->MouseSensitivity);
-	ui->checkForUpdates->setChecked(options->CheckForUpdates != 0);
+	ui->povrayExecutable->setText(options->POVRayPath);
+	ui->lgeoPath->setText(options->LGEOPath);
+	ui->mouseSensitivity->setValue(options->Preferences.mMouseSensitivity);
+	ui->checkForUpdates->setCurrentIndex(options->CheckForUpdates);
 	ui->centimeterUnits->setChecked((options->Snap & LC_DRAW_CM_UNITS) != 0);
 	ui->noRelativeSnap->setChecked((options->Snap & LC_DRAW_GLOBAL_SNAP) != 0);
 	ui->fixedDirectionKeys->setChecked((options->Snap & LC_DRAW_MOVEAXIS) != 0);
@@ -37,17 +41,26 @@ lcQPreferencesDialog::lcQPreferencesDialog(QWidget *parent, void *data) :
 		ui->antiAliasingSamples->setCurrentIndex(1);
 	else
 		ui->antiAliasingSamples->setCurrentIndex(0);
-	ui->edgeLines->setChecked((options->Detail & LC_DET_BRICKEDGES) != 0);
-	ui->lineWidth->setText(QString::number(options->LineWidth));
-	ui->baseGrid->setChecked((options->Snap & LC_DRAW_GRID) != 0);
-	ui->gridUnits->setText(QString::number(options->GridSize));
-	ui->axisIcon->setChecked((options->Snap & LC_DRAW_AXIS) != 0);
-	ui->enableLighting->setChecked((options->Detail & LC_DET_LIGHTING) != 0);
-	ui->fastRendering->setChecked((options->Detail & LC_DET_FAST) != 0);
+	ui->edgeLines->setChecked(options->Preferences.mDrawEdgeLines);
+	ui->lineWidth->setText(QString::number(options->Preferences.mLineWidth));
+	ui->gridStuds->setChecked(options->Preferences.mDrawGridStuds);
+	ui->gridLines->setChecked(options->Preferences.mDrawGridLines);
+	ui->gridLineSpacing->setText(QString::number(options->Preferences.mGridLineSpacing));
+	ui->axisIcon->setChecked(options->Preferences.mDrawAxes);
+	ui->enableLighting->setChecked(options->Preferences.mLightingMode != LC_LIGHTING_FLAT);
+
+	QPixmap pix(12, 12);
+
+	pix.fill(QColor(LC_RGBA_RED(options->Preferences.mGridStudColor), LC_RGBA_GREEN(options->Preferences.mGridStudColor), LC_RGBA_BLUE(options->Preferences.mGridStudColor)));
+	ui->gridStudColor->setIcon(pix);
+
+	pix.fill(QColor(LC_RGBA_RED(options->Preferences.mGridLineColor), LC_RGBA_GREEN(options->Preferences.mGridLineColor), LC_RGBA_BLUE(options->Preferences.mGridLineColor)));
+	ui->gridLineColor->setIcon(pix);
 
 	on_antiAliasing_toggled();
 	on_edgeLines_toggled();
-	on_baseGrid_toggled();
+	on_gridStuds_toggled();
+	on_gridLines_toggled();
 
 	updateCategories();
 	ui->categoriesTree->setCurrentItem(ui->categoriesTree->topLevelItem(0));
@@ -65,14 +78,22 @@ lcQPreferencesDialog::~lcQPreferencesDialog()
 
 void lcQPreferencesDialog::accept()
 {
-	options->Detail &= ~(LC_DET_BRICKEDGES | LC_DET_LIGHTING | LC_DET_FAST);
-	options->Snap &= ~(LC_DRAW_CM_UNITS | LC_DRAW_GLOBAL_SNAP | LC_DRAW_MOVEAXIS | LC_DRAW_GRID | LC_DRAW_AXIS);
+	int gridLineSpacing = ui->gridLineSpacing->text().toInt();
+	if (gridLineSpacing < 1)
+	{
+		QMessageBox::information(this, "LeoCAD", tr("Grid spacing must be greater than 0."));
+		return;
+	}
+
+	options->Snap &= ~(LC_DRAW_CM_UNITS | LC_DRAW_GLOBAL_SNAP | LC_DRAW_MOVEAXIS);
 
 	strcpy(options->DefaultAuthor, ui->authorName->text().toLocal8Bit().data());
 	strcpy(options->ProjectsPath, ui->projectsFolder->text().toLocal8Bit().data());
 	strcpy(options->LibraryPath, ui->partsLibrary->text().toLocal8Bit().data());
-	options->MouseSensitivity = ui->mouseSensitivity->value();
-	options->CheckForUpdates = ui->checkForUpdates->isChecked() ? 1 : 0;
+	strcpy(options->POVRayPath, ui->povrayExecutable->text().toLocal8Bit().data());
+	strcpy(options->LGEOPath, ui->lgeoPath->text().toLocal8Bit().data());
+	options->Preferences.mMouseSensitivity = ui->mouseSensitivity->value();
+	options->CheckForUpdates = ui->checkForUpdates->currentIndex();
 
 	if (ui->centimeterUnits->isChecked())
 		options->Snap |= LC_DRAW_CM_UNITS;
@@ -92,26 +113,15 @@ void lcQPreferencesDialog::accept()
 	else
 		options->AASamples = 2;
 
-	if (ui->edgeLines->isChecked())
-	{
-		options->Detail |= LC_DET_BRICKEDGES;
-		options->LineWidth = ui->lineWidth->text().toFloat();
-	}
+	options->Preferences.mDrawEdgeLines = ui->edgeLines->isChecked();
+	options->Preferences.mLineWidth = ui->lineWidth->text().toFloat();
 
-	if (ui->baseGrid->isChecked())
-	{
-		options->Snap |= LC_DRAW_GRID;
-		options->GridSize = ui->gridUnits->text().toInt();
-	}
+	options->Preferences.mDrawGridStuds = ui->gridStuds->isChecked();
+	options->Preferences.mDrawGridLines = ui->gridLines->isChecked();
+	options->Preferences.mGridLineSpacing = gridLineSpacing;
 
-	if (ui->axisIcon->isChecked())
-		options->Snap |= LC_DRAW_AXIS;
-
-	if (ui->enableLighting->isChecked())
-		options->Detail |= LC_DET_LIGHTING;
-
-	if (ui->fastRendering->isChecked())
-		options->Detail |= LC_DET_FAST;
+	options->Preferences.mDrawAxes = ui->axisIcon->isChecked();
+	options->Preferences.mLightingMode = ui->enableLighting->isChecked() ? LC_LIGHTING_FULL : LC_LIGHTING_FLAT;
 
 	QDialog::accept();
 }
@@ -132,6 +142,62 @@ void lcQPreferencesDialog::on_partsLibraryBrowse_clicked()
 		ui->partsLibrary->setText(QDir::toNativeSeparators(result));
 }
 
+void lcQPreferencesDialog::on_povrayExecutableBrowse_clicked()
+{
+#ifdef Q_OS_WIN
+	QString filter(tr("Executable Files (*.exe);;All Files (*.*)"));
+#else
+	QString filter(tr("All Files (*.*)"));
+#endif
+
+	QString result = QFileDialog::getOpenFileName(this, tr("Open POV-Ray Executable"), ui->povrayExecutable->text(), filter);
+
+	if (!result.isEmpty())
+		ui->povrayExecutable->setText(QDir::toNativeSeparators(result));
+}
+
+void lcQPreferencesDialog::on_lgeoPathBrowse_clicked()
+{
+	QString result = QFileDialog::getExistingDirectory(this, tr("Open LGEO Folder"), ui->lgeoPathBrowse->text());
+
+	if (!result.isEmpty())
+		ui->lgeoPathBrowse->setText(QDir::toNativeSeparators(result));
+}
+
+void lcQPreferencesDialog::colorClicked()
+{
+	QObject *button = sender();
+	QString title;
+	lcuint32 *color = NULL;
+	QColorDialog::ColorDialogOptions dialogOptions;
+
+	if (button == ui->gridStudColor)
+	{
+		color = &options->Preferences.mGridStudColor;
+		title = tr("Select Grid Stud Color");
+		dialogOptions = QColorDialog::ShowAlphaChannel;
+	}
+	else if (button == ui->gridLineColor)
+	{
+		color = &options->Preferences.mGridLineColor;
+		title = tr("Select Grid Line Color");
+		dialogOptions = 0;
+	}
+
+	QColor oldColor = QColor(LC_RGBA_RED(*color), LC_RGBA_GREEN(*color), LC_RGBA_BLUE(*color), LC_RGBA_ALPHA(*color));
+	QColor newColor = QColorDialog::getColor(oldColor, this, title, dialogOptions);
+
+	if (newColor == oldColor || !newColor.isValid())
+		return;
+
+	*color = LC_RGBA(newColor.red(), newColor.green(), newColor.blue(), newColor.alpha());
+
+	QPixmap pix(12, 12);
+
+	pix.fill(newColor);
+	((QToolButton*)button)->setIcon(pix);
+}
+
 void lcQPreferencesDialog::on_antiAliasing_toggled()
 {
 	ui->antiAliasingSamples->setEnabled(ui->antiAliasing->isChecked());
@@ -142,9 +208,14 @@ void lcQPreferencesDialog::on_edgeLines_toggled()
 	ui->lineWidth->setEnabled(ui->edgeLines->isChecked());
 }
 
-void lcQPreferencesDialog::on_baseGrid_toggled()
+void lcQPreferencesDialog::on_gridStuds_toggled()
 {
-	ui->gridUnits->setEnabled(ui->baseGrid->isChecked());
+	ui->gridStudColor->setEnabled(ui->gridStuds->isChecked());
+}
+
+void lcQPreferencesDialog::on_gridLines_toggled()
+{
+	ui->gridLineColor->setEnabled(ui->gridLines->isChecked());
 }
 
 void lcQPreferencesDialog::updateCategories()
@@ -181,7 +252,7 @@ void lcQPreferencesDialog::updateParts()
 
 	if (categoryIndex != -1)
 	{
-		PtrArray<PieceInfo> singleParts, groupedParts;
+		lcArray<PieceInfo*> singleParts, groupedParts;
 
 		library->SearchPieces(options->Categories[categoryIndex].Keywords, false, singleParts, groupedParts);
 
@@ -295,7 +366,7 @@ void lcQPreferencesDialog::on_importCategories_clicked()
 	char fileName[LC_MAXPATH];
 	strcpy(fileName, result.toLocal8Bit().data());
 
-	ObjArray<lcLibraryCategory> categories;
+	lcArray<lcLibraryCategory> categories;
 	if (!lcLoadCategories(fileName, categories))
 	{
 		QMessageBox::warning(this, "LeoCAD", tr("Error loading categories file."));
