@@ -253,8 +253,13 @@ lcQPropertiesTree::lcQPropertiesTree(QWidget *parent) :
 	labels.append(tr("Property"));
 	labels.append(tr("Value"));
 	setHeaderLabels(labels);
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 0, 0))
+	header()->setSectionsMovable(false);
+	header()->setSectionResizeMode(QHeaderView::ResizeToContents);
+#else
 	header()->setMovable(false);
 	header()->setResizeMode(QHeaderView::ResizeToContents);
+#endif
 	header()->setVisible(false);
 	setAlternatingRowColors(true);
 	setRootIsDecorated(false);
@@ -751,7 +756,7 @@ void lcQPropertiesTree::setPart(Object *newFocusObject)
 		partShow = addProperty(partVisibility, tr("Show"), PropertyInt);
 		partHide = addProperty(partVisibility, tr("Hide"), PropertyInt);
 
-		partAppearance = addProperty(NULL, tr("Appearence"), PropertyGroup);
+		partAppearance = addProperty(NULL, tr("Appearance"), PropertyGroup);
 		partColor = addProperty(partAppearance, tr("Color"), PropertyColor);
 		partID = addProperty(partAppearance, tr("Part"), PropertyPart);
 	}
@@ -778,17 +783,8 @@ void lcQPropertiesTree::setPart(Object *newFocusObject)
 	partRotationZ->setText(1, QString::number(rotation[2]));
 	partRotationZ->setData(0, PropertyValueRole, rotation[2]);
 
-	lcuint32 show, hide;
-	if (lcGetActiveProject()->IsAnimation())
-	{
-		show = part->GetFrameShow();
-		hide = part->GetFrameHide();
-	}
-	else
-	{
-		show = part->GetStepShow();
-		hide = part->GetStepHide();
-	}
+	lcuint32 show = part->GetStepShow();
+	lcuint32 hide = part->GetStepHide();
 
 	partShow->setText(1, QString::number(show));
 	partShow->setData(0, PropertyValueRole, show);
