@@ -154,8 +154,12 @@ int main(int argc, char *argv[])
 	const char* libPath = LC_INSTALL_PREFIX"/share/leocad/";
 #endif
 
-
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 0, 0))
+	QStringList cachePathList = QStandardPaths::standardLocations(QStandardPaths::CacheLocation);
+	QString cachePath = cachePathList.first();
+#else
 	QString cachePath = QDesktopServices::storageLocation(QDesktopServices::CacheLocation);
+#endif
 
 	QDir dir;
 	dir.mkdir(cachePath);
@@ -495,20 +499,20 @@ void lcMainWindow::UpdatePaste(bool Enabled)
 		window->updatePaste(Enabled);
 }
 
-void lcMainWindow::UpdateTime(bool Animation, int CurrentTime, int TotalTime)
+void lcMainWindow::UpdateTime(int CurrentTime, int TotalTime)
 {
 	lcQMainWindow* window = (lcQMainWindow*)mHandle;
 
 	if (window)
-		window->updateTime(Animation, CurrentTime, TotalTime);
+		window->updateTime(CurrentTime, TotalTime);
 }
 
-void lcMainWindow::UpdateAnimation(bool Animation, bool AddKeys)
+void lcMainWindow::UpdateAnimation(bool AddKeys)
 {
 	lcQMainWindow* window = (lcQMainWindow*)mHandle;
 
 	if (window)
-		window->updateAnimation(Animation, AddKeys);
+		window->updateAnimation(AddKeys);
 }
 
 void lcMainWindow::UpdateLockSnap(lcuint32 Snap)
